
Welcome to pyDAL's API documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 4
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Subpackages
-----------

.. toctree::

    pydal.adapters
    pydal.helpers

Submodules
----------

pydal.base module
---------------------

.. automodule:: pydal.base
    :members:
    :undoc-members:
    :show-inheritance:

pydal.connection module
---------------------------

.. automodule:: pydal.connection
    :members:
    :undoc-members:
    :show-inheritance:

pydal.objects module
------------------------

.. automodule:: pydal.objects
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pydal
    :members:
    :undoc-members:
    :show-inheritance:
